-- Drop-down menu handler

import "Turbine.UI.Lotro"

local Black = Turbine.UI.Color(0,0,0)
local Bronze = Turbine.UI.Color(229/255,209/255,136/255)
local Highlight = Turbine.UI.Color(0.85,0.65,0)
local Grey = Turbine.UI.Color(0.63,0.63,0.63)
local White = Turbine.UI.Color(1,1,1)

DropMenu = class(Turbine.UI.Control)

function DropMenu:Constructor()
	Turbine.UI.Control.Constructor(self)
    self:SetBackColor(Grey)
	self:SetVisible(true)

	self.Menu = Turbine.UI.Label()
	self.Menu:SetParent(self)
	self.Menu:SetPosition(2,2)
	self.Menu:SetHeight(16)
	self.Menu:SetOutlineColor(Highlight)
    self.Menu:SetBackColor(Black)
	self.Menu:SetForeColor(Bronze)
	self.Menu:SetTextAlignment( Turbine.UI.ContentAlignment.MiddleCenter )
	self.Menu:SetFont( Turbine.UI.Lotro.Font.TrajanPro14 )

	function self.Menu:MouseClick()
		if self.menu then
			self.menu:Close()
			self.menu = nil
			return
		end
		self.Click()
		if self.menu then
			local x,y = self:PointToScreen(0,20)
			self.menu:ShowMenuAt(x,y)
		end
	end

	-- Drop down arrow shown in the control.
	self.arrow = Turbine.UI.Control()
	self.arrow:SetParent(self.Menu)
	self.arrow:SetSize(14,14)
	self.arrow:SetBackground(0x41007e18)
	self.arrow:SetStretchMode(2)

end

function DropMenu:SizeChanged()
	local x,y = self:GetSize()
	self.Menu:SetSize(x-4, y-4)
	self.arrow:SetPosition(x- 18, y-18)
end

function DropMenu:SetText(text)
	self.Menu:SetText(text)
end

function DropMenu:GetText()
	return self.Menu:GetText()
end

function DropMenu:MouseEnter()
	self.arrow:SetBackground(0x41007e1b)
	self.Menu:SetForeColor(White)
	self.Menu:SetFontStyle(8)
end

function DropMenu:MouseLeave()
	self.arrow:SetBackground(0x41007e18)
	self.Menu:SetForeColor(Bronze)
	self.Menu:SetFontStyle(0)
end

function DropMenu:BuildMenu(list,action)
	local menu = Turbine.UI.ContextMenu()
	local menuItems,Item = menu:GetItems()
	local selected = self.Menu:GetText()
	for i,name in ipairs(list) do
        Item = Turbine.UI.MenuItem(name)
        if name==selected then
			Item:SetChecked(true)
		end
        Item.Click = function( sender,args )
            selected = sender:GetText()
			self.Menu:SetText(selected)
			print( "Selected "..selected )
			if action then action(selected) end
			self.Menu.menu = nil
        end
        menuItems:Add( Item )
	end
	self.Menu.menu = menu
end

