-- Warband Reference window handler

import "Turbine.UI.Lotro"
import "Vinny.Common"
import "Vinny.Common.DropMenu"

local labelFont = Turbine.UI.Lotro.Font.TrajanPro14
local foreColor = Turbine.UI.Color( 0.9, 0.9, 0 )
local backColor = Turbine.UI.Color( 0, 0, 0.05 )
local White = Turbine.UI.Color( 1, 1, 1 )
local Label = Turbine.UI.Label
local TextBox = Turbine.UI.TextBox
local Button = Turbine.UI.Lotro.Button
local DropMenu = Vinny.Common.DropMenu
local All,Select = "<All>","<All>"

WR_Window = class( Turbine.UI.Lotro.Window )

function WR_Window:AddField(control, text, pos, size, color)
	local field = control()
	field:SetParent( self )
	if text then field:SetText( text ) end
	field:SetPosition( pos.x,pos.y )
	field:SetSize( size.x,size.y )
	if control==Button or control==DropMenu or not text then return field end
	field:SetFont( labelFont )
	field:SetForeColor( color or foreColor )
	field:SetBackColor( backColor )
	field:SetTextAlignment( Turbine.UI.ContentAlignment.LeftCenter )
	return field
end

function WR_Window:BuildMenu(list,button)
	local Menu = Turbine.UI.ContextMenu()
	local menuItems,Item = Menu:GetItems()
	local selected = button:GetText()
	for i,name in ipairs(list) do
        Item = Turbine.UI.MenuItem(name)
        if name==selected then Item:SetChecked(true) end
        Item.Click = function( sender,args )
            if selected == sender:GetText() then selected = All
            else selected = sender:GetText() end
			button:SetText(selected)
			print( "Selected "..selected )
			if button.Action then
				button:Action(selected)
			end
        end
        menuItems:Add( Item )
	end
	return Menu
end

function WR_Window:Constructor()
	Turbine.UI.Lotro.Window.Constructor( self )

	-- Position the window near the top and to left of center of the screen.
	self:SetSize( 275,310 )
	pos = { x=Turbine.UI.Display.GetWidth()/6, y=Turbine.UI.Display.GetHeight()/4 }
	self:SetPosition( pos.x, pos.y )
	self:SetText( "Warband Ref." )

	-- Zone label and menu
	self:AddField(Label, "Zone:", {x=20,y=45}, {x=45,y=16} )
	self.zoneMenu = self:AddField(DropMenu, "", {x=90,y=43}, {x=140,y=20} )
	local action = function()
		self.wbMenu:SetText( "" )
	end
	self.zoneMenu.Menu.Click = function() self.zoneMenu:BuildMenu(zones,action) end

	-- Warband label and menu
	self:AddField(Label, "Warband:", {x=20,y=70}, {x=65,y=16} )
	self.wbMenu = self:AddField(DropMenu, "", {x=90,y=68}, {x=140,y=20} )
	self.wbMenu.Menu.Click = function()
		local zone = self.zoneMenu:GetText()
		if zone~="" then
			local wb_list = {}
			for name,t in pairs(WB) do
				if t.z==zone then table.insert(wb_list,name) end
			end
			table.sort(wb_list)
			self.wbMenu:BuildMenu(wb_list, WB_Show)
		else print("Select a zone.") end
	end

	-- Reward box color
	self:AddField(Label, "Reward box color:", {x=20,y=100}, {x=130,y=16} )
	self.box = self:AddField(Label, "", {x=152,y=100}, {x=40,y=16}, White )

	-- Warband location
	self:AddField(Label, "Spawn location:", {x=20,y=120}, {x=115,y=16} )
	self.loc = self:AddField(Label, "", {x=140,y=120}, {x=95,y=17}, White )

	-- Warband level
	self:AddField(Label, "Level:", {x=20,y=140}, {x=45,y=16} )
	self.level = self:AddField(Label, "", {x=60,y=140}, {x=24,y=16}, White )

	-- Leader type
	self:AddField(Label, "Leader type:", {x=90,y=140}, {x=80,y=16} )
	self.type = self:AddField(Label, "", {x=172,y=140}, {x=95,y=16}, White )

	-- Leader morale
	self:AddField(Label, "Leader morale:", {x=20,y=160}, {x=95,y=16} )
	self.morale = self:AddField(Label, "", {x=125,y=160}, {x=75,y=16}, White )

	-- Leader mount
	self:AddField(Label, "Mounted:", {x=20,y=180}, {x=65,y=16} )
	self.mount = self:AddField(Label, "", {x=90,y=180}, {x=30,y=16}, White )

	-- Leader combat
	self:AddField(Label, "Combat:", {x=120,y=180}, {x=70,y=16} )
	self.combat = self:AddField(Label, "", {x=178,y=180}, {x=75,y=16}, White )

	-- Allies
	self:AddField(Label, "Allies:", {x=20,y=200}, {x=65,y=16} )
	self.allies = self:AddField(Label, "", {x=65,y=200}, {x=40,y=16}, White )
	self.ally = { }
	for i = 1,3 do
		local t,y = { }, 200+i*16
		self.ally[i] = t
		t.nr = self:AddField(Label, "", {x=30,y=y}, {x=14,y=16}, White )
		t.mnt = self:AddField(Label, "", {x=45,y=y}, {x=60,y=16}, White )
		t.cb = self:AddField(Label, "", {x=115,y=y}, {x=70,y=16}, White )
		t.tp = self:AddField(Label, "", {x=180,y=y}, {x=85,y=16}, White )
	end

	-- Notes
	self:AddField(Label, "Note:", {x=20,y=270}, {x=70,y=16} )
	self.note = self:AddField(Label, "", {x=60,y=270}, {x=200,y=16}, White )

end

function WB_Show(name)
	local wb = WB[name]
	WR_window.box:SetText(wb and Box[wb.B])
	WR_window.loc:SetText(wb and wb.l)
	WR_window.level:SetText(wb and wb.L)
	WR_window.type:SetText(wb and Diff[wb.D])
	WR_window.morale:SetText(wb and wb.M)
	local s = wb and wb.C
	WR_window.mount:SetText(s and Mnt[s:sub(1,1)])
	WR_window.combat:SetText(s and Combat[s:sub(2)])
	local s = wb and wb.A
	WR_window.allies:SetText(s==" " and "None")
	for i = 1,3 do
		local t,x = WR_window.ally[i], i*4-3
		t.nr:SetText(s and s:sub(x,x))
		t.mnt:SetText(s and Combat[s:sub(x+2,x+2)])
		t.cb:SetText(s and Combat[s:sub(x+3,x+3)])
		t.tp:SetText(s and Diff[s:sub(x+1,x+1)])
	end
	WR_window.note:SetText(wb and wb.N)
end

WRW_Command = Turbine.ShellCommand()
local help_text = "wrw (open RR window)"
function WRW_Command:GetShortHelp() return "wrw (RR window commands)" end
function WRW_Command:GetHelp() return help_text end

function WRW_Command:Execute( command,args )
    WR_window:SetVisible( true )
	local target = player:GetTarget()
	if target then
		local name = target:GetName()
		local wb = WB[name]
		if wb then
			WR_window.zoneMenu:SetText( wb.z )
			WR_window.wbMenu:SetText( name )
			WB_Show(name)
		end
	end
end

Turbine.Shell.AddCommand( "wrw",WRW_Command )
